==> keyclic_sdk_api-1.28.3.tar.gz: lib/model/person_patch.dart <==
part of keyclic_sdk_api.api;

class PersonPatch {
  
  String givenName = null;
  

  String familyName = null;
  

  String email = null;
  

  String jobTitle = null;
  

  String image = null;
  

  bool optIn = null;
  

  String preferencesMessageEmailEnabled = null;
  

  String preferencesMessagePushEnabled = null;
  
  PersonPatch();

  @override
  String toString() {
    return 'PersonPatch[givenName=$givenName, familyName=$familyName, email=$email, jobTitle=$jobTitle, image=$image, optIn=$optIn, preferencesMessageEmailEnabled=$preferencesMessageEmailEnabled, preferencesMessagePushEnabled=$preferencesMessagePushEnabled, ]';
  }

  PersonPatch.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    givenName =
        json['givenName']
    ;
    familyName =
        json['familyName']
    ;
    email =
        json['email']
    ;
    jobTitle =
        json['jobTitle']
    ;
    image =
        json['image']
    ;
    optIn =
        json['optIn']
    ;
    preferencesMessageEmailEnabled =
        json['preferencesMessageEmailEnabled']
    ;
    preferencesMessagePushEnabled =
        json['preferencesMessagePushEnabled']
    ;
  }

  Map<String, dynamic> toJson() {
    return {
      'givenName': givenName,
      'familyName': familyName,
      'email': email,
      'jobTitle': jobTitle,
      'image': image,
      'optIn': optIn,
      'preferencesMessageEmailEnabled': preferencesMessageEmailEnabled,
      'preferencesMessagePushEnabled': preferencesMessagePushEnabled
     };
  }

  static List<PersonPatch> listFromJson(List<dynamic> json) {
    return json == null ? new List<PersonPatch>() : json.map((value) => new PersonPatch.fromJson(value)).toList();
  }

  static Map<String, PersonPatch> mapFromJson(Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, PersonPatch>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) => map[key] = new PersonPatch.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.28.6.tar.gz: lib/model/person_patch.dart <==
part of keyclic_sdk_api.api;

class PersonPatch {
  String givenName = null;

  String familyName = null;

  String email = null;

  String jobTitle = null;

  String image = null;

  bool optIn = null;

  String preferencesMessageEmailEnabled = null;

  String preferencesMessagePushEnabled = null;

  PersonPatch();

  @override
  String toString() {
    return 'PersonPatch[givenName=$givenName, familyName=$familyName, email=$email, jobTitle=$jobTitle, image=$image, optIn=$optIn, preferencesMessageEmailEnabled=$preferencesMessageEmailEnabled, preferencesMessagePushEnabled=$preferencesMessagePushEnabled, ]';
  }

  PersonPatch.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    givenName = json['givenName'];
    familyName = json['familyName'];
    email = json['email'];
    jobTitle = json['jobTitle'];
    image = json['image'];
    optIn = json['optIn'];
    preferencesMessageEmailEnabled = json['preferencesMessageEmailEnabled'];
    preferencesMessagePushEnabled = json['preferencesMessagePushEnabled'];
  }

  Map<String, dynamic> toJson() {
    return {
      'givenName': givenName,
      'familyName': familyName,
      'email': email,
      'jobTitle': jobTitle,
      'image': image,
      'optIn': optIn,
      'preferencesMessageEmailEnabled': preferencesMessageEmailEnabled,
      'preferencesMessagePushEnabled': preferencesMessagePushEnabled
    };
  }

  static List<PersonPatch> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<PersonPatch>()
        : json.map((value) => new PersonPatch.fromJson(value)).toList();
  }

  static Map<String, PersonPatch> mapFromJson(
      Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, PersonPatch>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) =>
          map[key] = new PersonPatch.fromJson(value));
    }
    return map;
  }
}
